@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.59 2005/10/13 03:14:11 philipl Exp $
+ *  $Id: ephy-embed.h,v 1.63 2006/01/08 22:28:09 jframeau Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -134,6 +134,7 @@ struct _EphyEmbedIface
 					 gpointer event);
 	void	 (* popup_blocked)	(EphyEmbed *embed,
 					 const char *address,
+					 const char *target,
 					 const char *features);
 	void	 (* security_change)	(EphyEmbed *embed,
 					 EphyEmbedSecurityLevel level);
@@ -141,6 +142,8 @@ struct _EphyEmbedIface
 					 float new_zoom);
 	void	 (* content_change)	(EphyEmbed *embed,
 					 const char *uri);
+	void	 (* content_blocked)	(EphyEmbed *embed,
+					 const char *uri);
 	gboolean (* modal_alert)	(EphyEmbed *embed);
 	void	 (* modal_alert_closed)	(EphyEmbed *embed);
 	void	 (* document_type)	(EphyEmbed *embed,
@@ -191,6 +194,13 @@ struct _EphyEmbedIface
 	void		   (* set_zoom)			(EphyEmbed *embed,
 							 float zoom);
 	float		   (* get_zoom)			(EphyEmbed *embed);
+	void		   (* scroll_lines)		(EphyEmbed *embed,
+							 int num_lines);
+	void		   (* scroll_pages)		(EphyEmbed *embed,
+	 						 int num_pages);
+	void		   (* scroll_pixels)		(EphyEmbed *embed,
+							 int dx,
+							 int dy);
 	char *		   (* get_encoding)		(EphyEmbed *embed);
 	gboolean	   (* has_automatic_encoding)	(EphyEmbed *embed);
 	void		   (* set_encoding)		(EphyEmbed *embed,
@@ -204,6 +214,7 @@ struct _EphyEmbedIface
 							 int page);
 	gboolean	   (* has_modified_forms)	(EphyEmbed *embed);
 	void		   (* close)			(EphyEmbed *embed);
+
 };
 
 GType 		  ephy_embed_net_state_get_type		(void);
@@ -282,6 +293,17 @@ void		  ephy_embed_set_zoom			(EphyEmbed *embed,
 
 float		  ephy_embed_get_zoom			(EphyEmbed *embed);
 
+/* Scroll */
+void		  ephy_embed_scroll			(EphyEmbed *embed,
+							 int num_lines);
+
+void		  ephy_embed_page_scroll		(EphyEmbed *embed,
+							 int num_pages);
+							 
+void		  ephy_embed_scroll_pixels		(EphyEmbed *embed,
+							 int dx,
+							 int dy);
+
 /* Encoding */
 char		 *ephy_embed_get_encoding		(EphyEmbed *embed);
 
