@@ -15,30 +15,28 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.51 2005/12/07 17:54:57 chpe Exp $
+ *  $Id: EphyBrowser.h,v 1.52 2006/05/10 18:07:00 chpe Exp $
  */
 
 #ifndef EPHY_BROWSER_H
 #define EPHY_BROWSER_H
 
-#include "config.h"
-
 #include "ephy-embed.h"
 #include <gtk/gtkwidget.h>
 
 #include <gtkmozembed.h>
 #include <nsCOMPtr.h>
-#include <nsIDOMEventListener.h>
 #include <nsIDOMContextMenuListener.h>
-#include <nsIDOMEventTarget.h>
-#include <nsIWebNavigation.h>
-#include <nsISHistory.h>
-#include <nsIWebBrowser.h>
-#include <nsIWebBrowserFocus.h>
 #include <nsIDOMDocument.h>
+#include <nsIDOMEventListener.h>
+#include <nsIDOMEventTarget.h>
 #include <nsIDOMWindow.h>
 #include <nsIPrintSettings.h>
 #include <nsIRequest.h>
+#include <nsISHistory.h>
+#include <nsIWebBrowserFocus.h>
+#include <nsIWebBrowser.h>
+#include <nsIWebNavigation.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsIContentViewer.h>
@@ -188,11 +186,6 @@ public:
 
         EphyEmbedDocumentType GetDocumentType ();
 
-#ifndef HAVE_GECKO_1_8
-	nsresult FocusActivate ();
-	nsresult FocusDeactivate ();
-#endif /* !HAVE_GECKO_1_8 */
-
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
 private:
 	GtkWidget *mEmbed;
