@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyContentPolicy.h,v 1.4 2005/01/11 19:15:26 chpe Exp $
+ *  $Id: EphyContentPolicy.h,v 1.7 2006/05/10 18:07:00 chpe Exp $
  */
 
 #ifndef EPHY_CONTENT_POLICY_H
@@ -25,9 +25,10 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <nsISupports.h>
 #include <nsIContentPolicy.h>
 
+#include "ephy-embed.h"
+
 #define EPHY_CONTENT_POLICY_CONTRACTID	"@gnome.org/projects/epiphany/epiphany-content-policy;1"
 #define EPHY_CONTENT_POLICY_CLASSNAME	"Epiphany Content Policy Class"
 
@@ -48,7 +49,8 @@ public:
 	EphyContentPolicy();
 	virtual ~EphyContentPolicy();
 private:
-	GObject *mEmbedSingle;
+	static GtkWidget *GetEmbedFromContext (nsISupports *aContext);
+
 	gboolean mLocked;
 	GSList *mSafeProtocols;
 };
