@@ -15,67 +15,54 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyFind.cpp,v 1.6.2.2 2006/07/23 11:14:54 chpe Exp $
+ *  $Id: EphyFind.cpp,v 1.7 2006/05/10 18:07:00 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "EphyFind.h"
-
-#include "ephy-debug.h"
-
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-
-#include <gtkmozembed.h>
-#include <gtkmozembed_internal.h>
-#include <nsCOMPtr.h>
-#include <nsIServiceManager.h>
-#include <nsIInterfaceRequestorUtils.h>
-#include <nsIDOMWindow.h>
-#include <nsIWebBrowser.h>
-#include <nsIWebBrowserFocus.h>
-#include <nsIDOMNode.h>
-#include <nsIDOMElement.h>
-#include <nsIDOMDocument.h>
-#include <nsIDOMDocumentView.h>
-#include <nsIDOMAbstractView.h>
-#include <nsIDOMDocumentEvent.h>
-#include <nsIDOMEvent.h>
-#include <nsIDOMKeyEvent.h>
-#include <nsIDOMEventTarget.h>
-#include <nsIDOMHTMLAnchorElement.h>
-
-#ifdef HAVE_TYPEAHEADFIND
-#include <nsISimpleEnumerator.h>
-#include <nsIDocShell.h>
-#include <nsIDocShellTreeItem.h>
-#include <nsITypeAheadFind.h>
-#include <nsISelectionDisplay.h>
-#include <nsISelectionController.h>
-#else
-#include <nsIWebBrowserFind.h>
-#include <nsMemory.h>
-#endif
-
 #include <glib.h>
 
-#ifdef HAVE_TYPEAHEADFIND
+#include <nsStringAPI.h>
+
+#include <gtkmozembed.h>
+#include <gtkmozembed_internal.h>
+#include <nsComponentManagerUtils.h>
+#include <nsCOMPtr.h>
+#include <nsIDocShell.h>
+#include <nsIDocShellTreeItem.h>
+#include <nsIDOMAbstractView.h>
+#include <nsIDOMDocumentEvent.h>
+#include <nsIDOMDocument.h>
+#include <nsIDOMDocumentView.h>
+#include <nsIDOMElement.h>
+#include <nsIDOMEvent.h>
+#include <nsIDOMEventTarget.h>
+#include <nsIDOMHTMLAnchorElement.h>
+#include <nsIDOMKeyEvent.h>
+#include <nsIDOMNode.h>
+#include <nsIDOMWindow.h>
+#include <nsIInterfaceRequestorUtils.h>
+#include <nsISelectionController.h>
+#include <nsISelectionDisplay.h>
+#include <nsISimpleEnumerator.h>
+#include <nsITypeAheadFind.h>
+#include <nsIWebBrowserFocus.h>
+#include <nsIWebBrowser.h>
+#include <nsServiceManagerUtils.h>
+
+#include "ephy-debug.h"
+
+#include "EphyFind.h"
+
 #define NS_TYPEAHEADFIND_CONTRACTID "@mozilla.org/typeaheadfind;1"
-#endif /* HAVE_TYPEAHEADFIND */
 
 static const PRUnichar kKeyEvents[] = { 'K', 'e', 'y', 'E', 'v', 'e', 'n', 't', 's', '\0' };
 static const PRUnichar kKeyPress[] = { 'k', 'e', 'y', 'p', 'r', 'e', 's', 's', '\0' };
 
 EphyFind::EphyFind ()
 : mCurrentEmbed(nsnull)
-#ifdef HAVE_TYPEAHEADFIND
 , mAttention(PR_FALSE)
-, mHasFocus(PR_FALSE)
-#endif
 {
   LOG ("EphyFind ctor [%p]", this);
 }
@@ -101,7 +88,6 @@ EphyFind::SetEmbed (EphyEmbed *aEmbed)
 				   getter_AddRefs (mWebBrowser));
   NS_ENSURE_TRUE (mWebBrowser, rv);
 
-#ifdef HAVE_TYPEAHEADFIND
   nsCOMPtr<nsIDocShell> docShell (do_GetInterface (mWebBrowser, &rv));
   NS_ENSURE_SUCCESS (rv, rv);
 
@@ -110,31 +96,11 @@ EphyFind::SetEmbed (EphyEmbed *aEmbed)
     NS_ENSURE_SUCCESS (rv, rv);
 
     rv = mFinder->Init (docShell);
-#ifdef HAVE_GECKO_1_9
-//    mFinder->SetSelectionModeAndRepaint (nsISelectionController::SELECTION_ON);
-#else
     mFinder->SetFocusLinks (PR_TRUE);
-#endif
   } else {
     rv = mFinder->SetDocShell (docShell);
   }
   NS_ENSURE_SUCCESS (rv, rv);
-#else
-  PRUnichar *string = nsnull;
-  if (mFinder) {
-    mFinder->GetSearchString (&string);
-  }
-
-  mFinder = do_GetInterface (mWebBrowser, &rv);
-  NS_ENSURE_SUCCESS (rv, rv);
-
-  mFinder->SetWrapFind (PR_TRUE);
-
-  if (string) {
-    mFinder->SetSearchString (string);
-    nsMemory::Free (string);    
-  }
-#endif /* HAVE_TYPEAHEADFIND */
 
   mCurrentEmbed = aEmbed;
 
@@ -147,40 +113,17 @@ EphyFind::SetFindProperties (const char *aSearchString,
 {
   if (!mFinder) return;
 
-#ifdef HAVE_TYPEAHEADFIND
   mFinder->SetCaseSensitive (aCaseSensitive);
   /* search string is set on ::Find */
-#else 
-  mFinder->SetMatchCase (aCaseSensitive);
-  
-  nsEmbedString uSearchString;
-  NS_CStringToUTF16 (nsEmbedCString (aSearchString ? aSearchString : ""),
-		     NS_CSTRING_ENCODING_UTF8, uSearchString);
-  
-  mFinder->SetSearchString (uSearchString.get ());
-#endif /* TYPEAHEADFIND */
 }
 
 void
 EphyFind::SetSelectionAttention (PRBool aAttention)
 {
-#ifdef HAVE_TYPEAHEADFIND
   if (aAttention == mAttention) return;
 
   mAttention = aAttention;
 
-  PRInt16 display;
-  if (aAttention) {
-    display = nsISelectionController::SELECTION_ATTENTION;
-  } else {
-    display = nsISelectionController::SELECTION_ON;
-  }
-
-#ifdef HAVE_GECKO_1_9
-  if (mFinder) {
-    mFinder->SetSelectionModeAndRepaint (display);
-  }
-#else
   nsresult rv;
   nsCOMPtr<nsIDocShell> shell (do_GetInterface (mWebBrowser, &rv));
   /* It's okay for this to fail, if the tab is closing, or if
@@ -194,6 +137,13 @@ EphyFind::SetSelectionAttention (PRBool aAttention)
 				     getter_AddRefs (enumerator));
   NS_ENSURE_SUCCESS (rv, );
 
+  PRInt16 display;
+  if (aAttention) {
+    display = nsISelectionController::SELECTION_ATTENTION;
+  } else {
+    display = nsISelectionController::SELECTION_ON;
+  }
+
   PRBool hasMore = PR_FALSE;
   while (NS_SUCCEEDED (enumerator->HasMoreElements (&hasMore)) && hasMore) {
     nsCOMPtr<nsISupports> element;
@@ -208,8 +158,6 @@ EphyFind::SetSelectionAttention (PRBool aAttention)
 
     controller->SetDisplaySelection (display);
   }
-#endif /* HAVE_GECKO_1_9 */
-#endif /* HAVE_TYPEAHEADFIND */
 }
 
 EphyEmbedFindResult
@@ -218,33 +166,17 @@ EphyFind::Find (const char *aSearchString,
 {
   if (!mFinder) return EPHY_EMBED_FIND_NOTFOUND;
 
-  nsEmbedString uSearchString;
-  NS_CStringToUTF16 (nsEmbedCString (aSearchString ? aSearchString : ""),
+  nsString uSearchString;
+  NS_CStringToUTF16 (nsCString (aSearchString ? aSearchString : ""),
   		     NS_CSTRING_ENCODING_UTF8, uSearchString);
 
-#ifdef HAVE_TYPEAHEADFIND
   SetSelectionAttention (PR_TRUE);
 
   nsresult rv;
   PRUint16 found = nsITypeAheadFind::FIND_NOTFOUND;
-#ifdef HAVE_GECKO_1_9
-  rv = mFinder->Find (uSearchString, aLinksOnly, mHasFocus, &found);
-#else
   rv = mFinder->Find (uSearchString, aLinksOnly, &found);
-#endif
 
   return (EphyEmbedFindResult) found;
-#else
-  mFinder->SetSearchString (uSearchString.get ());
-  mFinder->SetFindBackwards (PR_FALSE);
-
-  nsresult rv;
-  PRBool didFind = PR_FALSE;
-  rv = mFinder->FindNext (&didFind);
-        
-  return NS_SUCCEEDED (rv) && didFind ? EPHY_EMBED_FIND_FOUND :
-		  			EPHY_EMBED_FIND_NOTFOUND;
-#endif /* HAVE_TYPEAHEADFIND */
 }
 
 EphyEmbedFindResult
@@ -252,36 +184,17 @@ EphyFind::FindAgain (PRBool aForward)
 {
   if (!mFinder) return EPHY_EMBED_FIND_NOTFOUND;
 
-#ifdef HAVE_TYPEAHEADFIND
   SetSelectionAttention (PR_TRUE);
 
   nsresult rv;
   PRUint16 found = nsITypeAheadFind::FIND_NOTFOUND;
   if (aForward) {
-#ifdef HAVE_GECKO_1_9
-    rv = mFinder->FindNext (mHasFocus, &found);
-#else
     rv = mFinder->FindNext (&found);
-#endif
   } else {
-#ifdef HAVE_GECKO_1_9
-    rv = mFinder->FindPrevious (mHasFocus, &found);
-#else
     rv = mFinder->FindPrevious (&found);
-#endif
   }
 
   return (EphyEmbedFindResult) found;
-#else
-  mFinder->SetFindBackwards (!aForward);
-        
-  nsresult rv;
-  PRBool didFind = PR_FALSE;
-  rv = mFinder->FindNext (&didFind);
-
-  return NS_SUCCEEDED (rv) && didFind ? EPHY_EMBED_FIND_FOUND :
-		  EPHY_EMBED_FIND_NOTFOUND;
-#endif /* HAVE_TYPEAHEADFIND */
 }
 
 PRBool
@@ -289,21 +202,8 @@ EphyFind::ActivateLink (GdkModifierType aMask)
 {
 	nsresult rv;
 	nsCOMPtr<nsIDOMElement> link;
-#if defined(HAVE_TYPEAHEADFIND) && defined(HAVE_GECKO_1_8)
 	rv = mFinder->GetFoundLink (getter_AddRefs (link));
 	if (NS_FAILED (rv) || !link) return FALSE;
-#else
-	nsCOMPtr<nsIWebBrowserFocus> focus (do_QueryInterface (mWebBrowser));
-	NS_ENSURE_TRUE (focus, FALSE);
-
-	rv = focus->GetFocusedElement (getter_AddRefs (link));
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && link, FALSE);
-
-	/* ensure this is really a link so we don't accidentally submit if we're on a button or so! */
-	/* FIXME: does that work with xlink links? */
-	nsCOMPtr<nsIDOMHTMLAnchorElement> anchor (do_QueryInterface (link));
-	if (!anchor) return FALSE;
-#endif /* HAVE_TYPEAHEADFIND && HAVE_GECKO_1_8 */
 
 	nsCOMPtr<nsIDOMDocument> doc;
 	rv = link->GetOwnerDocument (getter_AddRefs (doc));
@@ -320,13 +220,13 @@ EphyFind::ActivateLink (GdkModifierType aMask)
 	NS_ENSURE_TRUE (docEvent, FALSE);
 
 	nsCOMPtr<nsIDOMEvent> event;
-	rv = docEvent->CreateEvent (nsEmbedString(kKeyEvents), getter_AddRefs (event));
+	rv = docEvent->CreateEvent (nsString(kKeyEvents), getter_AddRefs (event));
 	NS_ENSURE_SUCCESS (rv, FALSE);
 
 	nsCOMPtr<nsIDOMKeyEvent> keyEvent (do_QueryInterface (event));
 	NS_ENSURE_TRUE (keyEvent, FALSE);
 
-	rv = keyEvent->InitKeyEvent (nsEmbedString (kKeyPress),
+	rv = keyEvent->InitKeyEvent (nsString (kKeyPress),
 				     PR_TRUE /* bubble */,
 				     PR_TRUE /* cancelable */,
 				     abstractView,
