@@ -16,29 +16,25 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySidebar.cpp,v 1.6 2006/03/19 20:48:13 jframeau Exp $
+ *  $Id: EphySidebar.cpp,v 1.9 2006/05/12 12:40:10 chpe Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include <nsCOMPtr.h>
-#include <nsCRT.h>
-#include <nsIProgrammingLanguage.h>
+#include <nsStringAPI.h>
+
+#include <nsMemory.h>
 
 #ifdef HAVE_GECKO_1_9
 #include <nsIClassInfoImpl.h>
 #endif
 
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
-
-#include "EphySidebar.h"
+#include "ephy-debug.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
-#include "ephy-debug.h"
+
+#include "EphySidebar.h"
 
 NS_IMPL_ISUPPORTS1_CI(EphySidebar, nsISidebar)
 
@@ -56,10 +52,13 @@ EphySidebar::AddPanel (const PRUnichar *aTitle,
 		       const char *aContentURL,
 		       const char *aCustomizeURL)
 {
-	nsEmbedCString title;
+	NS_ENSURE_ARG (aTitle);
+	NS_ENSURE_ARG (aContentURL);
+
+	nsCString title;
 	EphyEmbedSingle *single;
 
-	NS_UTF16ToCString (nsEmbedString(aTitle),
+	NS_UTF16ToCString (nsDependentString(aTitle),
 			   NS_CSTRING_ENCODING_UTF8, title);
 
 	LOG ("Adding sidebar, url=%s title=%s", aContentURL, title.get());
@@ -90,10 +89,14 @@ EphySidebar::AddSearchEngine (const char *aEngineURL,
 			      const PRUnichar *aSuggestedTitle,
 			      const PRUnichar *aSuggestedCategory)
 {
-	nsEmbedCString title;
+	NS_ENSURE_ARG (aSuggestedTitle);
+	NS_ENSURE_ARG (aIconURL);
+	NS_ENSURE_ARG (aEngineURL);
+
+	nsCString title;
 	EphyEmbedSingle *single;
 
-	NS_UTF16ToCString (nsEmbedString(aSuggestedTitle),
+	NS_UTF16ToCString (nsDependentString(aSuggestedTitle),
 			   NS_CSTRING_ENCODING_UTF8, title);
 
 	LOG ("Adding search engine, engineurl=%s iconurl=%s title=%s", aEngineURL, aIconURL, title.get());
@@ -106,3 +109,14 @@ EphySidebar::AddSearchEngine (const char *aEngineURL,
 
 	return NS_OK;
 }
+
+#ifdef HAVE_GECKO_1_8_1
+
+/* void addMicrosummaryGenerator (in string generatorURL); */
+NS_IMETHODIMP
+EphySidebar::AddMicrosummaryGenerator (const char *generatorURL)
+{
+	return NS_ERROR_NOT_IMPLEMENTED;
+}
+
+#endif /* HAVE_GECKO_1_8_1 */
