@@ -16,18 +16,22 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GlobalHistory.h,v 1.10 2005/01/01 20:54:18 chpe Exp $
+ *  $Id: GlobalHistory.h,v 1.12 2006/05/10 18:07:00 chpe Exp $
  */
 
 #ifndef EPHY_GLOBAL_HISTORY_H
 #define EPHY_GLOBAL_HISTORY_H
 
-#include "ephy-history.h"
-
+#ifdef HAVE_NSIGLOBALHISTORY3_H
+#include <nsIGlobalHistory3.h>
+#else
 #include <nsIGlobalHistory2.h>
+#endif /* HAVE_NSIGLOBALHISTORY3_H */
 
-#include <nsCOMPtr.h>
 #include <nsAutoPtr.h>
+#include <nsCOMPtr.h>
+
+#include "ephy-history.h"
 
 #include "EphyHistoryListener.h"
 
@@ -40,7 +44,11 @@
 	{ 0xb7, 0x9e, 0xf7, 0xaa, 0x49, 0xeb, 0x6a, 0x15}	\
 }
 
+#ifdef HAVE_NSIGLOBALHISTORY3_H
+class MozGlobalHistory: public nsIGlobalHistory3
+#else
 class MozGlobalHistory: public nsIGlobalHistory2
+#endif /* HAVE_NSIGLOBALHISTORY3_H */
 {
 	public:
 		MozGlobalHistory ();
@@ -48,6 +56,9 @@ class MozGlobalHistory: public nsIGlobalHistory2
 
 		NS_DECL_ISUPPORTS
 		NS_DECL_NSIGLOBALHISTORY2
+#ifdef HAVE_NSIGLOBALHISTORY3_H
+		NS_DECL_NSIGLOBALHISTORY3
+#endif /* HAVE_NSIGLOBALHISTORY3_H */
 
 	private:
 		EphyHistory *mGlobalHistory;
