@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.49 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: MozRegisterComponents.cpp,v 1.50 2006/06/08 22:48:28 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -61,6 +61,10 @@
 #include "FilePicker.h"
 #endif
 
+#ifdef ENABLE_SPELLCHECKER
+#include "GeckoSpellCheckEngine.h"
+#endif
+
 #ifdef HAVE_MOZILLA_PSM
 #include "GtkNSSClientAuthDialogs.h"
 #include "GtkNSSDialogs.h"
@@ -81,6 +85,10 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
 #endif
 
+#ifdef ENABLE_SPELLCHECKER
+NS_GENERIC_FACTORY_CONSTRUCTOR(GeckoSpellCheckEngine)
+#endif
+
 #ifdef HAVE_MOZILLA_PSM
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSClientAuthDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
@@ -246,6 +254,14 @@ static const nsModuleComponentInfo sAppComps[] = {
 		EphyPromptServiceConstructor
 	},
 #endif /* HAVE_NSINONBLOCKINGALERTSERVICE_H */
+#ifdef ENABLE_SPELLCHECKER
+	{
+		GECKO_SPELL_CHECK_ENGINE_CLASSNAME,
+		GECKO_SPELL_CHECK_ENGINE_IID,
+		GECKO_SPELL_CHECK_ENGINE_CONTRACTID,
+		GeckoSpellCheckEngineConstructor
+	}
+#endif /* ENABLE_SPELLCHECK */
 };
 
 gboolean
