@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.c,v 1.71 2006/01/29 21:47:22 chpe Exp $
+ *  $Id: ephy-location-entry.c,v 1.74 2006/05/30 09:09:08 fpeters Exp $
  */
 
 #include "config.h"
@@ -337,9 +337,13 @@ update_favicon (EphyLocationEntry *entry)
 	}
 	else
 	{
-		gtk_image_set_from_stock (image,
-					  GTK_STOCK_NEW,
-					  GTK_ICON_SIZE_MENU);
+		/* Here we could consider using fallback favicon that matches
+		 * the page MIME type, though text/html should be good enough
+		 * most of the time. See #337140
+		 */
+		gtk_image_set_from_icon_name (image,
+					      "text-html",
+					      GTK_ICON_SIZE_MENU);
 	}
 }
 
@@ -425,7 +429,7 @@ keyword_match (const char *list,
 	  
 		next_token:
 
-		while (*p && *p != ' ') p++;
+		while (*p && !g_ascii_ispunct(*p)) p++;
 		if (*p) p++;
 	}
 
@@ -872,8 +876,7 @@ ephy_location_entry_init (EphyLocationEntry *le)
 	p->user_changed = TRUE;
 
 	p->tips = gtk_tooltips_new ();
-	g_object_ref (p->tips);
-	gtk_object_sink (GTK_OBJECT (p->tips));
+	g_object_ref_sink (p->tips);
 
 	ephy_location_entry_construct_contents (le);
 
