@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu.c,v 1.40 2005/12/05 20:54:16 chpe Exp $
+ *  $Id: ephy-tabs-menu.c,v 1.42 2006/04/25 11:40:41 chpe Exp $
  */
 
 #include "config.h"
@@ -54,7 +54,6 @@ struct _EphyTabsMenuPrivate
 	GtkActionGroup *action_group;
 	GtkAction *anchor_action;
 	guint ui_id;
-	guint num;
 };
 
 enum
@@ -130,9 +129,10 @@ sync_tab_title (EphyTab *tab,
 }
 
 static void
-tab_added_cb (EphyNotebook *notebook,
-	      EphyTab *tab,
-	      EphyTabsMenu *menu)
+notebook_page_added_cb (EphyNotebook *notebook,
+			EphyTab *tab,
+			guint position,
+			EphyTabsMenu *menu)
 {
 	EphyTabsMenuPrivate *priv = menu->priv;
 	GtkAction *action;
@@ -141,7 +141,8 @@ tab_added_cb (EphyNotebook *notebook,
 
 	LOG ("tab_added_cb tab=%p", tab);
 
-	g_snprintf (verb, sizeof (verb), ACTION_VERB_FORMAT, priv->num++);
+	g_snprintf (verb, sizeof (verb), ACTION_VERB_FORMAT,
+		    _ephy_tab_get_id (tab));
   
 	action = g_object_new (GTK_TYPE_RADIO_ACTION,
 			       "name", verb,
@@ -176,9 +177,10 @@ tab_added_cb (EphyNotebook *notebook,
 }
 
 static void
-tab_removed_cb (EphyNotebook *notebook,
-		EphyTab *tab,
-		EphyTabsMenu *menu)
+notebook_page_removed_cb (EphyNotebook *notebook,
+			  EphyTab *tab,
+			  guint position,
+			  EphyTabsMenu *menu)
 {
 	EphyTabsMenuPrivate *priv = menu->priv;
 	GtkAction *action;
@@ -201,8 +203,10 @@ tab_removed_cb (EphyNotebook *notebook,
 }
 
 static void
-tabs_reordered_cb (EphyNotebook *notebook,
-		   EphyTabsMenu *menu)
+notebook_page_reordered_cb (EphyNotebook *notebook,
+			    EphyTab *tab,
+			    guint position,
+			    EphyTabsMenu *menu)
 {
 	LOG ("tabs_reordered_cb");
  
@@ -246,6 +250,7 @@ sync_active_tab (EphyWindow *window,
 	/* happens initially, since the ::active-tab comes before
 	* the ::tab-added signal
 	*/
+	/* FIXME that's not true with gtk+ 2.9 anymore */
 	if (action == NULL) return;
 
 	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
@@ -278,12 +283,12 @@ ephy_tabs_menu_set_window (EphyTabsMenu *menu,
 			  G_CALLBACK (sync_active_tab), menu);
 
 	notebook = ephy_window_get_notebook (window);
-	g_signal_connect_object (notebook, "tab_added",
-				 G_CALLBACK (tab_added_cb), menu, 0);
-	g_signal_connect_object (notebook, "tab_removed",
-				 G_CALLBACK (tab_removed_cb), menu, 0);
-	g_signal_connect_object (notebook, "tabs_reordered",
-				 G_CALLBACK (tabs_reordered_cb), menu, 0);
+	g_signal_connect_object (notebook, "page-added",
+				 G_CALLBACK (notebook_page_added_cb), menu, 0);
+	g_signal_connect_object (notebook, "page-removed",
+				 G_CALLBACK (notebook_page_removed_cb), menu, 0);
+	g_signal_connect_object (notebook, "page-reordered",
+				 G_CALLBACK (notebook_page_reordered_cb), menu, 0);
 }
 
 static void
