@@ -1,3 +1,23 @@
+/* 
+ *  Copyright (C) 2005 Christian Persch
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: languages.h,v 1.5 2006/04/12 19:37:29 chpe Exp $
+ */
+
 static const char languages[][7] =
 {
 /* If you're missing your language/locale combination, file a bug at
@@ -170,6 +190,7 @@ static const char languages[][7] =
 "en-za",
 "en-zm",
 "en-zw",
+"eo",
 "es",
 "es-ar",
 "es-bo",
@@ -494,6 +515,7 @@ static const char languages[][7] =
 "tr-cy",
 "tr-tr",
 "ts",
+"tt",
 "tvl",
 "uk",
 "ur",
